import os, sys
import time
from math import sqrt
if 'SUMO_HOME' in os.environ:
    tools = os.path.join(os.environ['SUMO_HOME'], 'tools')
    sys.path.append(tools)
else:
    sys.exit("please declare environment variable 'SUMO_HOME'")

### debug with gui
# sumoBinary = "C:\\Users\\yyuan7\\Eclipse\\Sumo\\bin\\sumo-gui.exe"
sumoBinary = "C:\\Program Files (x86)\\Eclipse\\Sumo\\bin\\sumo-gui.exe"
sumoCmd = [sumoBinary, "-c", "demo.sumocfg"]

import traci
import random
random.seed(3)
import sumolib
from collections import defaultdict
import pandas as pd

def initial_config(sim_horizon):
    config = defaultdict()
    config['sim_horizon'] = sim_horizon
    return config

edges_list = ['E0','E1','E2','E3','E4','E5','E6']
o_edge = 'E0'
walking1 = ['E0','E1']
d_edge = 'E6'
walking2 = ['E5','E6']
pu_edge = 'E1'
do_edge = 'E5'
waiting_duration = 60


net_file = 'demo.net.xml'
net = sumolib.net.readNet(net_file)

stop_pos1 = net.getEdge(pu_edge).getLength()/2
stop_pos2 = net.getEdge(do_edge).getLength()/2

sim_horizon = 3600
step = 0
traci.start(sumoCmd)
config = initial_config(sim_horizon)

ped_id = 'ped_1'
veh_id = 'veh_1'

traci.route.add('route_1', edges_list)
traci.vehicle.add(veh_id, 'route_1', depart=20)
traci.vehicle.setStop(veh_id, pu_edge, pos =stop_pos1, duration = 60, laneIndex=1)
traci.vehicle.setStop(veh_id, do_edge, pos =stop_pos2, duration = 60, laneIndex=1)
traci.person.add(ped_id, o_edge, net.getEdge(o_edge).getLength()/2, depart = 0)
traci.person.appendWalkingStage(ped_id, walking1, stop_pos1)
traci.person.appendWaitingStage(ped_id, waiting_duration)

step = 0
while step < 1000:  # Simulate for 1000 steps (adjust as needed)
    traci.simulationStep()  # Advance the simulation by one step
    step += 1

    if traci.person.getStage(ped_id, 0).type == 1 and traci.person.getRoadID(ped_id) == pu_edge:
        print(ped_id, " Pickup!!!!!!!!!!!!!!")
        traci.person.removeStages(ped_id)
        traci.person.appendDrivingStage(ped_id, do_edge, veh_id)
        traci.person.appendWalkingStage(ped_id, walking2, net.getEdge(d_edge).getLength() / 2)
        traci.person.appendWaitingStage(ped_id, duration=99999)
    if traci.person.getRoadID(ped_id) == do_edge and traci.person.getVehicle(ped_id) == "":
        print(ped_id, " Arrived Destination!!!!!!!!!!!!!!")
    if traci.vehicle.getRoadID(veh_id) == edges_list[-1]:
        print("Vehicle has reached its destination")


